@@ -11,7 +11,7 @@ from logging import info
 from multiprocessing import cpu_count
 from pkg_resources import resource_filename
 
-from unogenerator.commons import __version__, addDebugSystem, argparse_epilog, ColorsNamed, Coord as C, next_port, get_from_process_numinstances_and_firstport
+from unogenerator.commons import __version__, addDebugSystem, argparse_epilog, ColorsNamed, Coord as C, next_port, get_from_process_numinstances_and_firstport, bytes_after_trim_image
 from unogenerator.reusing.currency import Currency
 from unogenerator.reusing.percentage import Percentage
 from unogenerator.unogenerator import ODT_Standard, ODS_Standard
@@ -137,7 +137,7 @@ def demo_ods_standard(language, port=2002, suffix="",):
         doc.createSheet("Styles")
         doc.setColumnsWidth([3.5, 5, 2, 2, 2, 2, 2, 5, 5, 3, 3])
         
-        
+        doc.setSheetStyle("Portrait")
         doc.setCellName("A1",  "MYNAME")
         
         doc.addCellWithStyle("A1", _("Style name"), ColorsNamed.Orange, "BoldCenter")
@@ -171,26 +171,50 @@ def demo_ods_standard(language, port=2002, suffix="",):
         doc.setComment("B14", "This is nice comment")
         
         doc.freezeAndSelect("B2")
+        
+        ## List of rows
+        doc.createSheet("List of rows or columns")
+        
+                
+        doc.addCellMergedWithStyle("A1:C1","List of rows with helper_totals_row", ColorsNamed.Orange, "BoldCenter")
+        range_=doc.addListOfRowsWithStyle("A2", [[1,2,3],[4,5,6],[7,8,9]], ColorsNamed.White)
+        helper_totals_row(doc, range_.c_start.addRowCopy(range_.numRows()), ["#SUM"]*3, styles=None, row_from="2", row_to="4")
+        
+        doc.addCellMergedWithStyle("A8:C8","List of columns with helper_totals_row", ColorsNamed.Orange, "BoldCenter")
+        range_=doc.addListOfColumnsWithStyle("A9", [[1,2,3],[4,5,6],[7,8,9]], ColorsNamed.White)
+        helper_totals_row(doc, range_.c_start.addRowCopy(range_.numRows()), ["#SUM"]*3, styles=None, row_from="9", row_to="11")
+
+        doc.addCellMergedWithStyle("A15:E15","List of rows with helper_totals_from_range in rows and columns", ColorsNamed.Orange, "BoldCenter")
+        range_=doc.addListOfRowsWithStyle("A16", [["A",12000,2,3, 6],["B",1020,5,6, 7],["C",20404,8,9, 8]], ColorsNamed.White)
+        helper_totals_from_range(doc, range_, totalcolumns=True, totalrows=True)
+        
+        
+        doc.addCellMergedWithStyle("A22:E22","List of rows with helper_totals_from_range in rows", ColorsNamed.Orange, "BoldCenter")
+        range_=doc.addListOfRowsWithStyle("A23", [["A",12000,2,3, 6],["B",1020,5,6, 7],["C",20404,8,9, 8]], ColorsNamed.White)
+        helper_totals_from_range(doc, range_.addColumnBefore(-1), totalcolumns=False, totalrows=True) #Removes one column to filter first alphanumerical column
+
+        doc.addCellMergedWithStyle("A29:E29","List of rows with helper_totals_from_range in columns", ColorsNamed.Orange, "BoldCenter")
+        range_=doc.addListOfRowsWithStyle("A30", [["A",12000,2,3, 6],["B",1020,5,6, 7],["C",20404,8,9, 8]], ColorsNamed.White)
+        helper_totals_from_range(doc, range_.addColumnBefore(-1), totalcolumns=True, totalrows=False)
+        
+        doc.addCellMergedWithStyle("A35:E35","List of rows with helper_totals_from_range in rows showing", ColorsNamed.Orange, "BoldCenter")
+        range_=doc.addListOfRowsWithStyle("A36", [["A",12000,2,3, 6],["B",1020,5,6, 7],["C",20404,8,9, 8]], ColorsNamed.White)
+        helper_totals_from_range(doc, range_.addColumnBefore(-1), totalcolumns=False, totalrows=True, showing=True)
+
+        doc.addCellMergedWithStyle("A42:E42","List of rows with helper_totals_from_range in columns showing", ColorsNamed.Orange, "BoldCenter")
+        range_=doc.addListOfRowsWithStyle("A43", [["A",12000,2,3, 6],["B",1020,5,6, 7],["C",20404,8,9, 8]], ColorsNamed.White)
+        helper_totals_from_range(doc, range_.addColumnBefore(-1), totalcolumns=True, totalrows=False, showing=True)
+
+        
 
         ## HELPERS
         doc.createSheet("Helpers")
+        doc.setSheetStyle("Portrait")
         doc.addCellMergedWithStyle("A1:E1","Helper values with total (horizontal)", ColorsNamed.Orange, "BoldCenter")
         helper_title_values_total_row(doc, "A2", "Suma 3", [1,2,3])
 
         doc.addCellMergedWithStyle("A4:A9","Helper values with total (vertical)", ColorsNamed.Orange, "VerticalBoldCenter")
         helper_title_values_total_column(doc, "B4", "Suma 3", [1,2,3, 4])
-        
-        doc.addCellMergedWithStyle("A11:C11","List of rows", ColorsNamed.Orange, "BoldCenter")
-        range_=doc.addListOfRowsWithStyle("A12", [[1,2,3],[4,5,6],[7,8,9]], ColorsNamed.White)
-        helper_totals_row(doc, range_.c_start.addRowCopy(range_.numRows()), ["#SUM"]*3, styles=None, row_from="12", row_to="14")
-        
-        doc.addCellMergedWithStyle("E11:G11","List of columns", ColorsNamed.Orange, "BoldCenter")
-        range_=doc.addListOfColumnsWithStyle("E12", [[1,2,3],[4,5,6],[7,8,9]], ColorsNamed.White)
-        helper_totals_row(doc, range_.c_start.addRowCopy(range_.numRows()), ["#SUM"]*3, styles=None, row_from="12", row_to="14")
-
-        doc.addCellMergedWithStyle("A17:D17","List of rows with totals", ColorsNamed.Orange, "BoldCenter")
-        range_=doc.addListOfRowsWithStyle("A18", [["A",12000,2,3],["B",1020,5,6],["C",20404,8,9]], ColorsNamed.White)
-        helper_totals_from_range(doc, range_, totalcolumns=True, totalrows=True)
 
         
         doc.addCellMergedWithStyle("A23:B23","List of ordered dictionaries", ColorsNamed.Orange, "BoldCenter")
@@ -388,6 +412,41 @@ def demo_odt_standard(language, port=2002, suffix=""):
 
         doc.addParagraph(_("The next paragraph is generated with the illustration method"), "Standard")
         doc.addImageParagraph([resource_filename(__name__, 'images/crown.png')]*5, 2.5, 1.5, "Illustration", linked=False)
+        
+        doc.addParagraph(_("The next paragraph is generated with the illustration method"), "Standard")
+        doc.addImageParagraph([resource_filename(__name__, 'images/crown.png')]*5, 2.5, 1.5, "Illustration", linked=False)
+        
+        
+        doc.addParagraph(_("You can play with image width and height:"), "Standard")
+        l=[]
+        l.append(doc.textcontentImage(resource_filename(__name__, 'images/icons.jpg'), None, None,  "AS_CHARACTER", "PRIMERA", linked=False))
+        l.append(" Image default size. Height and width are set to None.")
+        doc.addParagraphComplex(l, "Standard")
+        l=[]
+        l.append(doc.textcontentImage(resource_filename(__name__, 'images/icons.jpg'), 3,  None,  "AS_CHARACTER", "PRIMERA", linked=False))
+        l.append(" Image width 3cm of width and height automatically set.")
+        doc.addParagraphComplex(l, "Standard")
+        l=[]
+        l.append(doc.textcontentImage(resource_filename(__name__, 'images/icons.jpg'),  None, 3,  "AS_CHARACTER", "PRIMERA", linked=False))
+        l.append(" Image height 3cm of width and width automatically set.")
+        doc.addParagraphComplex(l, "Standard")
+        l=[]
+        l.append(doc.textcontentImage(resource_filename(__name__, 'images/icons.jpg'), 3, 3,  "AS_CHARACTER", "PRIMERA", linked=False))
+        l.append(" Image width and height set to 3cm.")
+        doc.addParagraphComplex(l, "Standard")
+        
+        
+        doc.addParagraph(_("You can trim image border white space when needed:"), "Standard")
+        
+        l=[]
+        l.append("This is a camerawith gray space around it: ")
+        l.append(doc.textcontentImage(resource_filename(__name__, 'images/Imagewithborder.png'), 1, None))
+        l.append(". ")
+        l.append(_("You can trim that gray space when needed with 'bytes_after_trim_image' method. To use this method you need Imagemagick installed to use 'convert' command. This is the result: "))
+        bytes_=bytes_after_trim_image(resource_filename(__name__, 'images/Imagewithborder.png'), "png")
+        l.append(doc.textcontentImage(bytes_, 1, None,))
+        doc.addParagraphComplex(l, "Standard")
+        
 
 
         doc.addParagraph(_("Search and Replace"), "Heading 2")
