@@ -274,11 +274,9 @@ class ODT(ODF):
     ## Find a string and deleteAll untill the end of the document
     ## Usefull to delete document part with styles in templates
     def find_and_delete_until_the_end_of_document(self, find):
-        search=self.document.createSearchDescriptor()
-        search.SearchString=find
-        found=self.document.findFirst(search)
+        found=self.find_and_replace(find, "", None, False)
         if found is not None:
-            found.setString("")
+#            found.setString("")
             self.cursor=found
             
             oVC = self.document.getCurrentController().getViewCursor()#		'Create View Cursor oVC at the end of document by default?
@@ -332,7 +330,14 @@ class ODT(ODF):
     ## @param filename_or_bytessequence, Can be a filename path or a bytesequence
     ## @param anchortype AS_CHARACTER, AT_PARAGRAPH
     ## @param name None if we want to use lo default name
-    def textcontentImage(self, filename_or_bytessequence, width=2,  height=2, anchortype="AS_CHARACTER", name=None, linked=False ):
+    ## @param width 
+    ## @param height Puede ser None or a value. If a value, witdth will be set  automatically
+    ##      -Width:None -Heigth:None. Usa tamaño por defecto de la imagen (Opción por defecto)
+    ##      - Width: 5  -Height:None. Pone 5cm de ancho y la altura automática
+    ##      - Width: None  -Height:None5. Pone la anchura automática y 5cm de alto
+    ##      - Width: 5  -Height:5. Pone 5cm de ancho de alto
+    
+    def textcontentImage(self, filename_or_bytessequence, width=None,  height=None, anchortype="AS_CHARACTER", name=None, linked=False ):
         if filename_or_bytessequence.__class__.__name__=="bytes":
             bytes_stream = self.ctx.ServiceManager.createInstanceWithContext('com.sun.star.io.SequenceInputStream', self.ctx)
             bytes_stream.initialize((ByteSequence(filename_or_bytessequence),)) ##Método para inicializar un servicio
@@ -351,6 +356,14 @@ class ODT(ODF):
         if name is not None:
             image.setName(name)
         image.AnchorType=anchortype
+        #Calculate sizes
+        if width is None and height is None:
+            width=graphic.Size100thMM.Width/1000
+            height=graphic.Size100thMM.Height/1000
+        elif width is None and height is not None:
+            width=round(height*graphic.Size100thMM.Width/graphic.Size100thMM.Height, 3)
+        elif height is None and width is not None:
+            height=round(width*graphic.Size100thMM.Height/graphic.Size100thMM.Width, 3)
         image.Size=Size(width*1000, height*1000)
         return image
         
@@ -468,6 +481,11 @@ class ODS(ODF):
     def setRemoveDefaultSheet(self, b):
         self._remove_default_sheet=b
         
+    ## Sets sheet pagestyle. If you use ODS_Standard you can set Default (Landscape) and Portrait
+    ## Usefull when exporting to pdf
+    def setSheetStyle(self, style):
+        self.sheet.PageStyle=style
+        
     def getSheetNames(self):        
         return self.document.Sheets.ElementNames
         
@@ -969,7 +987,10 @@ class ODS(ODF):
                 makedirs(path.dirname(path.abspath(filename)), exist_ok=True)
                 copyfile(tempfile, filename)
 
-    def export_pdf(self, filename):
+    ## If you want to set one page to portrait use setSheetStyle
+    ## @filename
+    ## @page_per_sheet If True exports pdf with a pdf page per sheet. If False makes a standard export
+    def export_pdf(self, filename, page_per_sheet=True):
         if self.getRemoveDefaultSheet() is True:
             self.removeDefaultSheet()
         
@@ -977,10 +998,23 @@ class ODS(ODF):
             print(_("Filename extension must be 'pdf'."))
             print(_("Document hasn't been saved."))
             return
-        args=(
-            PropertyValue('FilterName',0,'calc_pdf_Export',0),
-            PropertyValue('Overwrite',0,True,0),
-        )
+            
+        if page_per_sheet is True:
+            oStyleFamilies =self.document.getStyleFamilies()
+            oObj_1 = oStyleFamilies.getByName("PageStyles")
+            oObj_2 = oObj_1.getByName("Default")
+            oObj_2.ScaleToPagesX= 1
+            oObj_2.ScaleToPagesY = 1
+            args=(
+                PropertyValue('FilterName',0,'calc_pdf_Export',0),
+                PropertyValue('Overwrite',0,True,0),
+            )
+        else: #page_per_sheet False
+            args=(
+                PropertyValue('FilterName',0,'calc_pdf_Export',0),
+                PropertyValue('Overwrite',0,True,0),
+            )
+        
         with TemporaryDirectory() as tmpdirname:
             tempfile=f"{tmpdirname}/{path.basename(filename)}"
             self.document.storeToURL(systemPathToFileUrl(tempfile), args)
